psychopy_ext.stats.accuracy — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.stats.accuracy

`psychopy_ext.stats.` `accuracy`(df, values=None, correct='correct', incorrect='incorrect', **kwargs)

  Computes accuracy given correct and incorrect data labels.

  Args: | df (pandas.DataFrame) Your data
  Kwargs: | values (str or list of str, default: None) Name(s) of the column(s) that is aggregated correct (str or a number or list of str or numbers, default: None) Labels that are treated as correct responses. incorrect (str or a number or list of str or numbers, default: None) Labels that are treated as incorrect responses. kwargs Anything else you want to pass to `aggregate()`. Note that `aggfunc` is set to `np.size` and you cannot change that.
  Returns: | A pandas.DataFrame in the format of `accuracy()` where the reported values are a fraction correct / (correct+incorrect).
  See also: | `accuracy()`